chatter package
===============

Subpackages
-----------

.. toctree::

   chatter.api
   chatter.migrations
   chatter.test_utils

Submodules
----------

chatter.admin module
--------------------

.. automodule:: chatter.admin
   :members:
   :undoc-members:
   :show-inheritance:

chatter.apps module
-------------------

.. automodule:: chatter.apps
   :members:
   :undoc-members:
   :show-inheritance:

chatter.consumers module
------------------------

.. automodule:: chatter.consumers
   :members:
   :undoc-members:
   :show-inheritance:

chatter.forms module
--------------------

.. automodule:: chatter.forms
   :members:
   :undoc-members:
   :show-inheritance:

chatter.messages module
-----------------------

.. automodule:: chatter.messages
   :members:
   :undoc-members:
   :show-inheritance:

chatter.models module
---------------------

.. automodule:: chatter.models
   :members:
   :undoc-members:
   :show-inheritance:

chatter.routings module
-----------------------

.. automodule:: chatter.routings
   :members:
   :undoc-members:
   :show-inheritance:

chatter.urls module
-------------------

.. automodule:: chatter.urls
   :members:
   :undoc-members:
   :show-inheritance:

chatter.views module
--------------------

.. automodule:: chatter.views
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: chatter
   :members:
   :undoc-members:
   :show-inheritance:
